@@ -137,7 +137,7 @@ class JinjaStaticRenderer():
         try:
             os.stat(dir)
         except:
-            os.mkdir(dir)
+            os.makedirs(dir)
 
     def render(self, data_source):
         """
